==> open-xchange-guard-ui_2.4.2.orig.tar.bz2: open-xchange-guard-ui-2.4.2/oxguard-ui/spec/oxguard/settings_spec.js <==
define([
    'oxguard/settings/defaults',
    'spec/shared/capabilities',
    'settings!oxguard'
], function (defaults, caputil, settings) {
    'use strict';

    var capabilities = caputil.preset('common').init(['oxguard/settings/defaults'], [defaults]);

    describe('Guard settings', function () {
        describe('cryptoProvider defaults', function () {
            it('with cap=guard,-mailvelope,-forceMailvelope (guard only scenario)', function () {
                return capabilities
                    .enable(['guard'])
                    .then(function () {
                        return capabilities.disable(['mailvelope', 'forceMailvelope']);
                    })
                    .then(function () {
                        expect(defaults.cryptoProvider).to.equal('guard');
                    });
            });

            it('with cap=-guard,mailvelope,-forceMailvelope (mailvelope only scenario)', function () {
                return capabilities
                    .enable(['mailvelope'])
                    .then(function () {
                        return capabilities.disable(['guard', 'forceMailvelope']);
                    })
                    .then(function () {
                        expect(defaults.cryptoProvider).to.equal('mailvelope');
                    });
            });

            it('with cap=guard,mailvelope,forceMailvelope (admin enforces mailvelope usage scenario)', function () {
                return capabilities
                    .enable(['guard', 'mailvelope', 'forceMailvelope'])
                    .then(function () {
                        return capabilities.disable([]);
                    })
                    .then(function () {
                        expect(defaults.cryptoProvider).to.equal('mailvelope');
                    });
            });

            it('with cap=-guard,-mailvelope,-forceMailvelope (everything disabled scenario)', function () {
                return capabilities
                    .enable([])
                    .then(function () {
                        return capabilities.disable(['guard', 'mailvelope', 'forceMailvelope']);
                    })
                    .then(function () {
                        expect(defaults.cryptoProvider).not.to.be.defined;
                    });
            });

            it('with cap=guard,mailvelope,-forceMailvelope (user must choose scenario)', function () {
                return capabilities
                    .enable(['guard', 'mailvelope'])
                    .then(function () {
                        return capabilities.disable(['forceMailvelope']);
                    })
                    .then(function () {
                        expect(defaults.cryptoProvider).not.to.be.defined;
                    });
            });
        });
    });
});

==> open-xchange-guard-ui_2.10.6.orig.tar.bz2: open-xchange-guard-ui-2.10.6/oxguard-ui/spec/oxguard/settings_spec.js <==
define([
    'oxguard/settings/defaults',
    'spec/shared/capabilities'
], function (defaults, caputil) {
    'use strict';

    var capabilities = caputil.preset('common').init(['oxguard/settings/defaults'], [defaults]);

    describe('Guard settings', function () {
        describe('cryptoProvider defaults', function () {
            it('with cap=guard,-mailvelope,-forceMailvelope (guard only scenario)', function () {
                return capabilities
                    .enable(['guard'])
                    .then(function () {
                        return capabilities.disable(['mailvelope', 'forceMailvelope']);
                    })
                    .then(function () {
                        expect(defaults.cryptoProvider).to.equal('guard');
                    });
            });

            it('with cap=-guard,mailvelope,-forceMailvelope (mailvelope only scenario)', function () {
                return capabilities
                    .enable(['mailvelope'])
                    .then(function () {
                        return capabilities.disable(['guard', 'forceMailvelope']);
                    })
                    .then(function () {
                        expect(defaults.cryptoProvider).to.equal('mailvelope');
                    });
            });

            it('with cap=guard,mailvelope,forceMailvelope (admin enforces mailvelope usage scenario)', function () {
                return capabilities
                    .enable(['guard', 'mailvelope', 'forceMailvelope'])
                    .then(function () {
                        return capabilities.disable([]);
                    })
                    .then(function () {
                        expect(defaults.cryptoProvider).to.equal('mailvelope');
                    });
            });

            it('with cap=-guard,-mailvelope,-forceMailvelope (everything disabled scenario)', function () {
                return capabilities
                    .enable([])
                    .then(function () {
                        return capabilities.disable(['guard', 'mailvelope', 'forceMailvelope']);
                    })
                    .then(function () {
                        expect(defaults.cryptoProvider).not.to.be.defined;
                    });
            });

            it('with cap=guard,mailvelope,-forceMailvelope (user must choose scenario)', function () {
                return capabilities
                    .enable(['guard', 'mailvelope'])
                    .then(function () {
                        return capabilities.disable(['forceMailvelope']);
                    })
                    .then(function () {
                        expect(defaults.cryptoProvider).not.to.be.defined;
                    });
            });
        });
    });
});
